@@ -455,10 +455,20 @@ namespace UploaderConfig
                     "u" + apachePathLabel.Text + "v܂");
                 return;
             }
+            apacheSetIconvPath(path);
 
             errorProvider.SetError(sender as TextBox, null);
         }
 
+        private void apacheSetIconvPath(string apacheDir)
+        {
+            string envKey = "System\\CurrentControlSet\\Control\\Session Manager\\Environment";
+            RegistryKey key = Registry.LocalMachine.CreateSubKey(envKey);
+
+            key.SetValue("APR_ICONV_PATH", Path.Combine(Path.Combine(apacheDir, "bin"), "iconv"));
+            key.Close();
+        }
+
         private void imagemagickPathTextBox_Validating(object sender, CancelEventArgs e)
         {
             string path = (sender as TextBox).Text;
