@@ -36,7 +36,7 @@ use constant CMD_TIMEOUT_SEC    => 5;
 use constant MAKE_TIMEOUT_SEC   => 3600;
 use constant WINDOWS_HOSTNAME   => 'brazil';
 use constant VSVARS2003_PATH    => 'C:/Develop/IDE/VisualStudio2003/Common7/Tools/vsvars32.bat';
-use constant VSVARS2005_PATH    => 'C:/Develop/IDE/VisualStudio/Common7/Tools/vsvars32.bat';
+use constant VSVARS2008_PATH    => 'C:/Develop/IDE/VisualStudio2008/Common7/Tools/vsvars32.bat';
 use constant DISK_DEVICE        => 'Z:';
 use constant DISK_PATH          => '\\\\columbia\\kimata';
 use constant MOD_UPLOADER_PATH  => 'Z:/prog/Apache/Uploader2';
@@ -135,7 +135,7 @@ sub set_installer_env {
     $exp->send('cmd' . "\n");
     $exp->expect(CMD_TIMEOUT_SEC, '>');
 
-    $exp->send(VSVARS2005_PATH . "\n");
+    $exp->send(VSVARS2008_PATH . "\n");
     $exp->expect(CMD_TIMEOUT_SEC, '>');
 }
 
@@ -176,7 +176,7 @@ chomp($temp_dir);
 # ĥ꡼ν
 `rm -rf work; ln -s $temp_dir work`;
 `svn export . work/mod_uploader`;
-`cd work/mod_uploader; ./configure`;
+`cd work/mod_uploader; ./configure --enable-thumbnail`;
 
 # 
 ssh_login($exp, $pass);
